@@ -164,8 +164,8 @@ class JSProxyWidget(widgets.DOMWidget):
     _model_name = Unicode('JSProxyModel').tag(sync=True)
     _view_module = Unicode('jp_proxy_widget').tag(sync=True)
     _model_module = Unicode('jp_proxy_widget').tag(sync=True)
-    _view_module_version = Unicode('^1.0.7').tag(sync=True)
-    _model_module_version = Unicode('^1.0.7').tag(sync=True)
+    _view_module_version = Unicode('^1.0.8').tag(sync=True)
+    _model_module_version = Unicode('^1.0.8').tag(sync=True)
 
     # traitlet port to use for sending commands to javascript
     #commands = traitlets.List([], sync=True)
@@ -230,7 +230,7 @@ class JSProxyWidget(widgets.DOMWidget):
                 };
                 setTimeout(delayed, ms_delay);
             };
-        """, RECEIVE_FRAGILE_REFERENCE=self._RECEIVE_FRAGILE_REFERENCE)
+        """, RECEIVE_FRAGILE_REFERENCE=self._RECEIVE_FRAGILE_REFERENCE, callable_level=5)
 
     def set_element(self, slot_name, value):
         """
@@ -293,6 +293,22 @@ class JSProxyWidget(widgets.DOMWidget):
             action()
 
     def wrap_callables(self, x, callable_level=3):
+        def wrapit(x):
+            if callable(x) and not isinstance(x, CommandMakerSuperClass):
+                return self.callable(x, level=callable_level)
+            # otherwise
+            ty = type(x)
+            if ty is list:
+                return list(wrapit(y) for y in x)
+            if ty is tuple:
+                return tuple(wrapit(y) for y in x)
+            if ty is dict:
+                return dict((k, wrapit(v)) for (k,v) in x.items())
+            # default
+            return x
+        return wrapit(x)
+
+    def wrap_callables0(self, x, callable_level=3):
         if callable(x) and not isinstance(x, CommandMakerSuperClass):
             return self.callable(x, level=callable_level)
         w = self.wrap_callables
@@ -347,7 +363,7 @@ class JSProxyWidget(widgets.DOMWidget):
         if self.verbose:
             print("sending")
             pprint(package)
-        debug_check_commands(package)
+        #debug_check_commands(package)
         self.send(package)
 
     # slot for last message data debugging
@@ -1438,12 +1454,30 @@ class CallMaker(CommandMaker):
         return [self.kind] + self.args #+ validate_commands(self.args, False)
 
 
+def np_array_to_list(a):
+    return a.tolist()
+
+
 class LiteralMaker(CommandMaker):
     """
     Proxy to make a literal dictionary or list which may contain other
     proxy references.
     """
 
+    translators = {
+        np.ndarray: np_array_to_list,
+        np.float: float,
+        np.float128: float,
+        np.float16: float,
+        np.float32: float,
+        np.float64: float,
+        np.int: int,
+        np.int0: int,
+        np.int16: int,
+        np.int32: int,
+        np.int64: int,
+    }
+
     indicators = {
         # things we can translate
         dict: "dict", list: "list", bytearray: "bytes",
@@ -1463,7 +1497,7 @@ class LiteralMaker(CommandMaker):
     def _cmd(self):
         thing = self.thing
         ty = type(thing)
-        indicator = self.indicators.get(type(thing))
+        indicator = self.indicators.get(ty)
         #return [indicator, thing]
         if indicator:
             # exact type equality here:
@@ -1479,7 +1513,12 @@ class LiteralMaker(CommandMaker):
 
 
 def quoteIfNeeded(arg):
-    if type(arg) in LiteralMaker.indicators:
+    ty = type(arg)
+    translator = LiteralMaker.translators.get(ty)
+    if translator:
+        arg = translator(arg)
+        ty = type(arg)
+    if ty in LiteralMaker.indicators:
         return LiteralMaker(arg)
     return arg
 
